==> order-center-api-2.9.0-CLOUD-20220819.123154-6-sources.jar: com/tydic/dyc/oc/service/saleorder/bo/UocGetSaleOrderDetailServiceRspInvoiceBo.java <==
package com.tydic.dyc.oc.service.saleorder.bo;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocGetSaleOrderDetailServiceRspInvoiceBo
 * 说明:
 * 时间:2022/3/10 12:24
 * 作者:田桂银
 */
@Data
public class UocGetSaleOrderDetailServiceRspInvoiceBo implements Serializable {


    private static final long serialVersionUID = 7952638696358451825L;

    @DocField(value = "id")
    private Long id;

    @DocField(value = "订单id")
    private Long orderId;

    @DocField(value = "发票类型    1 普票   2 专票")
    private Integer invoiceType;

    @DocField(value = "发票类型翻译")
    private String invoiceTypeStr;

    @DocField(value = "发票类别：1电子，2纸质，默认1")
    private Integer invoceCategory;

    @DocField(value = "发票类别翻译")
    private String invoceCategoryStr;

    @DocField(value = "购买人或公司名称")
    private String buyerName;

    @DocField(value = "固定电话")
    private String fixPhone;

    @DocField(value = "税号")
    private String invoiceNo;

    @DocField(value = "单位地址")
    private String companyAddress;

    @DocField(value = "收货地址ID")
    private Long contactId;

    @DocField(value = "开户银行")
    private String depositBank;

    @DocField(value = "银行账户")
    private String bankAccount;

    @DocField(value = "发票号")
    private String invoiceSn;

    @DocField(value = "发票url")
    private String invoiceUrl;

    @DocField(value = "联系人电话")
    private String relaPhone;

    @DocField(value = "联系人邮箱")
    private String relaEmail;

    @DocField(value = "添加外部发票id")
    private String outInvoiceId;

    @DocField(value = "创建时间")
    private Date createTime;

    @DocField(value = "创建工号")
    private String createOperId;

    @DocField(value = "创建人")
    private String createOperName;

    @DocField(value = "更新时间")
    private Date updateTime;

    @DocField(value = "更新工号")
    private String updateOperId;

    @DocField(value = "更新人")
    private String updateOperName;

    @DocField(value = "备注")
    private String remark;

}

==> order-center-api-3.0.0-CLOUD-20230505.072403-53-sources.jar: com/tydic/dyc/oc/service/saleorder/bo/UocGetSaleOrderDetailServiceRspInvoiceBo.java <==
package com.tydic.dyc.oc.service.saleorder.bo;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocGetSaleOrderDetailServiceRspInvoiceBo
 * 说明:
 * 时间:2022/3/10 12:24
 * 作者:田桂银
 */
@Data
public class UocGetSaleOrderDetailServiceRspInvoiceBo implements Serializable {


    private static final long serialVersionUID = 7952638696358451825L;

    
    private Long id;

    /**
     * 订单id
     */
    private Long orderId;

    /**
     * 发票类型    1 普票   2 专票
     */
    private Integer invoiceType;

    /**
     * 发票类型翻译
     */
    private String invoiceTypeStr;

    /**发票类别：1电子，2纸质，默认1*/
    private Integer invoceCategory;

    /**发票类别翻译*/
    private String invoceCategoryStr;

    /**购买人或公司名称*/
    private String buyerName;

    /**固定电话*/
    private String fixPhone;

    /**税号*/
    private String invoiceNo;

    /**单位地址*/
    private String companyAddress;

    /**收货地址ID*/
    private Long contactId;

    /**开户银行*/
    private String depositBank;

    /**银行账户*/
    private String bankAccount;

    /**发票号*/
    private String invoiceSn;

    /**发票url*/
    private String invoiceUrl;

    /**联系人电话*/
    private String relaPhone;

    /**联系人邮箱*/
    private String relaEmail;

    /**添加外部发票id*/
    private String outInvoiceId;

    /**创建时间*/
    private Date createTime;

    /**创建工号*/
    private String createOperId;

    /**创建人*/
    private String createOperName;

    /**更新时间*/
    private Date updateTime;

    /**更新工号*/
    private String updateOperId;

    /**更新人*/
    private String updateOperName;

    /**
     * 备注
     */
    private String remark;

}
